@@ -20,7 +20,7 @@ def setup(app):
     app.add_css_file("main_stylesheet.css")
 
 
-extensions = ['breathe']
+extensions = ['breathe', 'sphinx_rtd_theme']
 breathe_projects = { 'xeus': '../xml' }
 templates_path = ['_templates']
 html_static_path = ['_static']
