@@ -12,11 +12,15 @@
 
 #include <string>
 
-#include "xeus.hpp"
+#include "xeus/xeus.hpp"
 
 namespace xeus
 {
-    XEUS_API std::string blocking_input_request(const std::string& prompt, bool password);
+    XEUS_API 
+    std::string blocking_input_request(
+        const std::string& prompt,
+        bool password
+    );
 }
 
 #endif
