@@ -10,16 +10,18 @@
 #ifndef XEUS_KERNEL_HPP
 #define XEUS_KERNEL_HPP
 
-#include "xdebugger.hpp"
-#include "xeus.hpp"
-#include "xeus_context.hpp"
-#include "xhistory_manager.hpp"
-#include "xinterpreter.hpp"
-#include "xkernel_configuration.hpp"
-#include "xserver.hpp"
-#include "xlogger.hpp"
 #include <memory>
 #include <string>
+#include <functional>
+
+#include "xeus/xdebugger.hpp"
+#include "xeus/xeus.hpp"
+#include "xeus/xeus_context.hpp"
+#include "xeus/xhistory_manager.hpp"
+#include "xeus/xinterpreter.hpp"
+#include "xeus/xkernel_configuration.hpp"
+#include "xeus/xserver.hpp"
+#include "xeus/xlogger.hpp"
 
 namespace xeus
 {
@@ -39,14 +41,14 @@ namespace xeus
         using logger_ptr = std::unique_ptr<xlogger>;
         using server_ptr = std::unique_ptr<xserver>;
         using debugger_ptr = std::unique_ptr<xdebugger>;
-        using server_builder = server_ptr (*)(xcontext& context,
-                                              const xconfiguration& config,
-                                              nl::json::error_handler_t eh);
-        using debugger_builder = debugger_ptr (*)(xcontext& context,
-                                                  const xconfiguration& config,
-                                                  const std::string&,
-                                                  const std::string&,
-                                                  const nl::json&);
+        using server_builder = std::function<server_ptr(xcontext& context,
+                                             const xconfiguration& config,
+                                             nl::json::error_handler_t eh)>;
+        using debugger_builder = std::function<debugger_ptr(xcontext& context,
+                                                const xconfiguration& config,
+                                                const std::string&,
+                                                const std::string&,
+                                                const nl::json&)>;
 
         xkernel(const xconfiguration& config,
                 const std::string& user_name,
