@@ -12,7 +12,7 @@
 
 #include <string>
 
-#include "xeus.hpp"
+#include "xeus/xeus.hpp"
 
 namespace xeus
 {
