@@ -12,7 +12,7 @@
 
 #include <string>
 
-#include "xeus.hpp"
+#include "xeus/xeus.hpp"
 
 namespace xeus
 {
@@ -25,11 +25,6 @@ namespace xeus
     XEUS_API
     int get_current_pid();
 
-    [[deprecated]] XEUS_API 
-    std::string get_cell_tmp_file(const std::string& prefix,
-                                  int execution_count,
-                                  const std::string& extension);
-
     XEUS_API
     std::size_t get_tmp_hash_seed();
 
@@ -40,6 +35,12 @@ namespace xeus
     std::string get_cell_tmp_file(const std::string& prefix,
                                   const std::string& code,
                                   const std::string& suffix);
+
+    XEUS_API
+    std::string executable_path();
+    
+    XEUS_API
+    std::string prefix_path();
 }
 
 #endif
